/*
 *     Arduino VFO Initial data writer
 *                          for DDS VFO Ver3         
 *                         JA2NKD 2016.10.18     
 *     Aruduino IDE 1.6.5
 *     Arduino nano only
 *     
 * <Rotary.h>    https://github.com/brianlow/Rotary
 * <EF_AD9850.h> http://forum.arduino.cc/index.php?topic=77483.0
 * "Ucglib.h"    https://github.com/olikraus/ucglib
 *
 */

// Library include
#include <SPI.h>
#include <EEPROM.h>
#include <Ucglib.h>

/*
 * Hardware SPI Pins:
 * Arduino nano sclk=13, data=11
 * 
*/

// I/O setting 

  const byte __CS=10;
  const byte __DC=9;
  const byte __RST=8;
  
Ucglib_ILI9341_18x240x320_HWSPI ucg(__DC, __CS, __RST);

// Variable setting
  unsigned long freq[4];
  int romadd=0x100;
  int fstep=100;
  int fmode=1;

/*
 * Step DATA 10Hz --> fstep=1 , 100Hz --> fstep=2 , 1KHz --> fstep=3 , 10KHz --> fstep=4
 * Mode DATA LSB --> fmode=0; , USB --> fmode=1 , CW --> fmode=2 AM -->fmode=3
 * freq[0] Dial frequency , freq[1] min frequency freq[2]= max frequency
 */
 
void setup() {

ucg.begin(UCG_FONT_MODE_TRANSPARENT);
ucg.clearScreen();
ucg.setRotate270();
ucg.setFont(ucg_font_ncenR14_tr);
ucg.setPrintPos(10,20);
ucg.setColor(255,0,0);
ucg.print("Hello");
ucg.setPrintPos(10,40);
ucg.setColor(0,255,255);
ucg.print("NKD_VFO ROM Write & Read test");

EEPROM.write(0x01,1);   //Power On BAND (0 to 9) 

// BAND:0 ROMadd:0x010 
  romadd=0x010;
  freq[0]=1800000;
  freq[1]=1000000;
  freq[2]=3000000;
  fmode=0;
  fstep=2;
  bandwrite();
  
// BAND:1 ROMadd:0x020
  romadd=0x020;
  freq[0]=3500000;
  freq[1]=3000000;
  freq[2]=5000000;
  fmode=0;
  fstep=2;
  bandwrite();
  
  // BAND:2 ROMadd:0x030
  romadd=0x030;
  freq[0]=5400000;
  freq[1]=5000000;
  freq[2]=7000000;
  fmode=2;
  fstep=1;
  bandwrite();

// BAND:3 ROMadd:0x040
  romadd=0x040;
  freq[0]=7000000;
  freq[1]=7000000;
  freq[2]=10000000;
  fmode=1;
  fstep=2;
  bandwrite();
  
// BAND:4 ROMadd:0x050
  romadd=0x050;
  freq[0]=10100000;
  freq[1]=10000000;
  freq[2]=14000000;
  fmode=2;
  fstep=1;
  bandwrite();
  
  // BAND:5 ROMadd:0x060
  romadd=0x060;
  freq[0]=14000000;
  freq[1]=14000000;
  freq[2]=18000000;
  fmode=1;
  fstep=2;
  bandwrite();
  
// BAND:6 ROMadd:0x070
  romadd=0x070;
  freq[0]=18068000;
  freq[1]=18000000;
  freq[2]=21000000;
  fmode=1;
  fstep=2;
  bandwrite();
  
// BAND:7 ROMadd:0x080
  romadd=0x080;
  freq[0]=21100000;
  freq[1]=21000000;
  freq[2]=24000000;
  fmode=1;
  fstep=2;
  bandwrite();

  // BAND:8 ROMadd:0x090
  romadd=0x090;
  freq[0]=24890000;
  freq[1]=24000000;
  freq[2]=28000000;
  fmode=1;
  fstep=2;
  bandwrite();

  // BAND:9 ROMadd:0x0a0
  romadd=0x0a0;
  freq[0]=28000000;
  freq[1]=28000000;
  freq[2]=30000000;
  fmode=1;
  fstep=2;
  bandwrite();
  
// Read test 
  ucg.setColor(255,255,255);
  for(int z=0; z<8; z++){
    romadd=0x10+(0x10*z);
    for (int i=0; i<3;i++){
      freq[i]=eepread((romadd+4*i));
    }
    fmode=EEPROM.read(romadd+12);
    fstep=EEPROM.read(romadd+13);
    ucg.setPrintPos(10,70+(20*z));
    for (int i=0; i<3;i++){
      ucg.print(freq[i]);
      ucg.print(" ");
    }
    ucg.print(fmode);
      ucg.print(" ");
    ucg.print(fstep);
  }
}
//Main Routine
void loop() {

}

 void bandwrite(){
  for (int i=0;i<3;i++){
 //   romadd=romadd+4;
    eepwrite(freq[i],(romadd+4*i));
  }
  EEPROM.write(romadd+12,fmode);
  EEPROM.write(romadd+13,fstep);
 }
 
void eepwrite(unsigned long f0,int epadd){
  for (int i=0; i<=3;i++){
  EEPROM.write(epadd+i,f0%256);
  f0=f0/256;
  }
}

unsigned long eepread(int epadd){
  unsigned long f0=0;
  for (int i=3; i >=0 ;i--){
    f0=f0*256+EEPROM.read(epadd+i);
    }
return f0;
}
